Simulated dataset containing the score on four achievement tests for 50 childrens attending the last year of primary school. The four tests are repeated five times at regular time intervals.
data(achievement)A data.frame with a total of 250 observations on the following 6 variables:
idChild identifier.
timeAssessment time (1 to 5).
speakingScore on speaking test (1=minimum, 5=maximum).
readingScore on reading test (1=minimum, 5=maximum).
writingScore on writing test (1=minimum, 5=maximum).
mathScore on math test (1=minimum, 5=maximum).
achievement